==> jc-1.4.0.tar.gz: polyglot/types/NoMemberException.h <==
// public class polyglot.types.NoMemberException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class 52ccd7a0cb95da9a polyglot_types_NoMemberException
// @dep_class 45f755f5298b5b39 polyglot_types_SemanticException

// header file dependencies
// @dep_header polyglot_types_SemanticException

#include "polyglot/types/SemanticException.h"

#ifndef _JC_polyglot_types_NoMemberException_H_
#define _JC_polyglot_types_NoMemberException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_polyglot_util_Position$object;

// Typedefs
typedef struct _jc_polyglot_types_NoMemberException$sub_refs	_jc_polyglot_types_NoMemberException$sub_refs;
typedef struct _jc_polyglot_types_NoMemberException$sub_nonrefs	_jc_polyglot_types_NoMemberException$sub_nonrefs;
typedef struct _jc_polyglot_types_NoMemberException$refs	_jc_polyglot_types_NoMemberException$refs;
typedef struct _jc_polyglot_types_NoMemberException$nonrefs	_jc_polyglot_types_NoMemberException$nonrefs;
typedef struct _jc_polyglot_types_NoMemberException$object	_jc_polyglot_types_NoMemberException$object;

typedef struct _jc_polyglot_types_NoMemberException$fields_struct	_jc_polyglot_types_NoMemberException$fields_struct;
typedef const struct _jc_polyglot_types_NoMemberException$vmethods	_jc_polyglot_types_NoMemberException$vmethods;
typedef const struct _jc_polyglot_types_NoMemberException$vtable	_jc_polyglot_types_NoMemberException$vtable;
typedef const struct _jc_polyglot_types_NoMemberException$vtype	_jc_polyglot_types_NoMemberException$vtype;

// Class fields structure
struct _jc_polyglot_types_NoMemberException$fields_struct {
	jint	CONSTRUCTOR;
	jint	FIELD;
	jint	METHOD;
};
extern _jc_polyglot_types_NoMemberException$fields_struct _jc_polyglot_types_NoMemberException$class_fields;

// Constructors
extern void _jc_polyglot_types_NoMemberException$method$_init$206934d97c5ba451(_jc_env *, struct _jc_polyglot_types_NoMemberException$object *, jint, struct _jc_java_lang_String$object *);
extern void _jc_polyglot_types_NoMemberException$method$_init$cdd55eca3cb7f7f4(_jc_env *, struct _jc_polyglot_types_NoMemberException$object *, jint, struct _jc_java_lang_String$object *, struct _jc_polyglot_util_Position$object *);

// Virtual methods
extern jint _jc_polyglot_types_NoMemberException$method$getKind$077249f218cf7d99(_jc_env *, struct _jc_polyglot_types_NoMemberException$object *);
extern struct _jc_java_lang_String$object *_jc_polyglot_types_NoMemberException$method$getKindStr$83109abbee8573ec(_jc_env *, struct _jc_polyglot_types_NoMemberException$object *);

// Virtual method descriptors
extern _jc_method _jc_polyglot_types_NoMemberException$method_info$getKind$077249f218cf7d99;
extern _jc_method _jc_polyglot_types_NoMemberException$method_info$getKindStr$83109abbee8573ec;

// Virtual methods structure
struct _jc_polyglot_types_NoMemberException$vmethods {
	jint	(*getKind$077249f218cf7d99)(_jc_env *, struct _jc_polyglot_types_NoMemberException$object *);
	struct _jc_java_lang_String$object	*(*getKindStr$83109abbee8573ec)(_jc_env *, struct _jc_polyglot_types_NoMemberException$object *);
};

// Vtable
struct _jc_polyglot_types_NoMemberException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_polyglot_types_SemanticException$vmethods	polyglot_types_SemanticException;
	_jc_polyglot_types_NoMemberException$vmethods	polyglot_types_NoMemberException;
};

// Vtype
struct _jc_polyglot_types_NoMemberException$vtype {
	_jc_type			type;
	_jc_polyglot_types_NoMemberException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_types_NoMemberException$sub_refs {
};

// Reference instance fields (object)
struct _jc_polyglot_types_NoMemberException$refs {
    _jc_polyglot_types_NoMemberException$sub_refs	polyglot_types_NoMemberException;
    _jc_polyglot_types_SemanticException$sub_refs	polyglot_types_SemanticException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_types_NoMemberException$sub_nonrefs {
	jint	kind;
};

// Non-reference instance fields (object)
struct _jc_polyglot_types_NoMemberException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_polyglot_types_SemanticException$sub_nonrefs	polyglot_types_SemanticException;
    _jc_polyglot_types_NoMemberException$sub_nonrefs	polyglot_types_NoMemberException;
};

// Object instance structure
struct _jc_polyglot_types_NoMemberException$object {
	_jc_polyglot_types_NoMemberException$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_types_NoMemberException$vtype	*vtype;
	_jc_polyglot_types_NoMemberException$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_types_NoMemberException$vtype _jc_polyglot_types_NoMemberException$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_types_NoMemberException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_types_NoMemberException$class_object;

#endif	/* _JC_polyglot_types_NoMemberException_H_ */

==> jc-1.4.6.tar.gz: polyglot/types/NoMemberException.h <==
// public class polyglot.types.NoMemberException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class 52ccd7a0cb95da9a polyglot_types_NoMemberException
// @dep_class 45f755f5298b5b39 polyglot_types_SemanticException

// header file dependencies
// @dep_header polyglot_types_SemanticException

#include "polyglot/types/SemanticException.h"

#ifndef _JC_polyglot_types_NoMemberException_H_
#define _JC_polyglot_types_NoMemberException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_polyglot_util_Position$object;

// Typedefs
typedef struct _jc_polyglot_types_NoMemberException$sub_refs	_jc_polyglot_types_NoMemberException$sub_refs;
typedef struct _jc_polyglot_types_NoMemberException$sub_nonrefs	_jc_polyglot_types_NoMemberException$sub_nonrefs;
typedef struct _jc_polyglot_types_NoMemberException$refs	_jc_polyglot_types_NoMemberException$refs;
typedef struct _jc_polyglot_types_NoMemberException$nonrefs	_jc_polyglot_types_NoMemberException$nonrefs;
typedef struct _jc_polyglot_types_NoMemberException$object	_jc_polyglot_types_NoMemberException$object;

typedef struct _jc_polyglot_types_NoMemberException$fields_struct	_jc_polyglot_types_NoMemberException$fields_struct;
typedef const struct _jc_polyglot_types_NoMemberException$vmethods	_jc_polyglot_types_NoMemberException$vmethods;
typedef const struct _jc_polyglot_types_NoMemberException$vtable	_jc_polyglot_types_NoMemberException$vtable;
typedef const struct _jc_polyglot_types_NoMemberException$vtype	_jc_polyglot_types_NoMemberException$vtype;

// Class fields structure
struct _jc_polyglot_types_NoMemberException$fields_struct {
	jint	CONSTRUCTOR;
	jint	FIELD;
	jint	METHOD;
};
extern _jc_polyglot_types_NoMemberException$fields_struct _jc_polyglot_types_NoMemberException$class_fields;

// Constructors
extern void _jc_polyglot_types_NoMemberException$method$_init$206934d97c5ba451(_jc_env *, struct _jc_polyglot_types_NoMemberException$object *, jint, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern void _jc_polyglot_types_NoMemberException$method$_init$cdd55eca3cb7f7f4(_jc_env *, struct _jc_polyglot_types_NoMemberException$object *, jint, struct _jc_java_lang_String$object *, struct _jc_polyglot_util_Position$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jint _jc_polyglot_types_NoMemberException$method$getKind$077249f218cf7d99(_jc_env *, struct _jc_polyglot_types_NoMemberException$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_polyglot_types_NoMemberException$method$getKindStr$83109abbee8573ec(_jc_env *, struct _jc_polyglot_types_NoMemberException$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_polyglot_types_NoMemberException$method_info$getKind$077249f218cf7d99;
extern _jc_method _jc_polyglot_types_NoMemberException$method_info$getKindStr$83109abbee8573ec;

// Virtual methods structure
struct _jc_polyglot_types_NoMemberException$vmethods {
	jint	(*getKind$077249f218cf7d99)(_jc_env *, struct _jc_polyglot_types_NoMemberException$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getKindStr$83109abbee8573ec)(_jc_env *, struct _jc_polyglot_types_NoMemberException$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_polyglot_types_NoMemberException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_polyglot_types_SemanticException$vmethods	polyglot_types_SemanticException;
	_jc_polyglot_types_NoMemberException$vmethods	polyglot_types_NoMemberException;
};

// Vtype
struct _jc_polyglot_types_NoMemberException$vtype {
	_jc_type			type;
	_jc_polyglot_types_NoMemberException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_types_NoMemberException$sub_refs {
};

// Reference instance fields (object)
struct _jc_polyglot_types_NoMemberException$refs {
    _jc_polyglot_types_NoMemberException$sub_refs	polyglot_types_NoMemberException;
    _jc_polyglot_types_SemanticException$sub_refs	polyglot_types_SemanticException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_types_NoMemberException$sub_nonrefs {
	jint	kind;
};

// Non-reference instance fields (object)
struct _jc_polyglot_types_NoMemberException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_polyglot_types_SemanticException$sub_nonrefs	polyglot_types_SemanticException;
    _jc_polyglot_types_NoMemberException$sub_nonrefs	polyglot_types_NoMemberException;
};

// Object instance structure
struct _jc_polyglot_types_NoMemberException$object {
	_jc_polyglot_types_NoMemberException$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_types_NoMemberException$vtype	*vtype;
	_jc_polyglot_types_NoMemberException$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_types_NoMemberException$vtype _jc_polyglot_types_NoMemberException$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_types_NoMemberException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_types_NoMemberException$class_object;

#endif	/* _JC_polyglot_types_NoMemberException_H_ */
